using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace NumericTextBox
{
  public partial class NumericTextBox : System.Windows.Forms.TextBox 
  {
    public NumericTextBox()
    {
      this.BackColor = Color.Yellow;
      this.ForeColor = Color.Blue;
      this.Font = new Font("Arial", 10);
      this.HasDecimal = true;
      this.HasNegative = false;
    }
    private bool hasDecimal;
    [Category("Behavior")] public bool HasDecimal
    {
      get
      {
        return hasDecimal;
      }
      set
      {
        hasDecimal = value;
      }
    }
    private bool hasNegative;
    [Category("Behavior")] public bool HasNegative
    {
      get
      {
        return hasNegative;
      }
      set
      {
        hasNegative = value;
      }
    }
    protected override void OnKeyPress(System.Windows.Forms.KeyPressEventArgs e)
    {
      // check pressed key
      if ((e.KeyChar >= '0' && e.KeyChar <= '9') || (int)e.KeyChar == 8)
      {
        // allow numbers or backspace
        e.Handled = false;
      }
      else if (e.KeyChar == '.')
      {
        // allow decimal if HasDecimal is True
        if (hasDecimal)
        {
          // allow only one
          if (this.Text.IndexOf(".") == -1)
          {
            e.Handled = false;
          }
          else
          {
            e.Handled = true;
          }
        }
        else
        {
          e.Handled = true;
        }
      }
      else if (e.KeyChar == '-')
      {
        // allow single negative sign in first position only if HasNegative is True
        if (hasNegative)
        {
          if (this.Text.IndexOf("-") != -1 || this.SelectionStart != 0)
          {
            e.Handled = true;
          }
          else
          {
            e.Handled = false;
          }
        }
        else
        {
          e.Handled = true;
        }
      }
      else
      {
        // no other keys allowed
        e.Handled = true;
      }
    }
  }
}